@@ -32,3 +32,11 @@ def get_subpackage_paths():
     for finder, modname, ispkg in pkgutil.iter_modules(stratus_api.__path__):
         subpackage_path = os.path.join(finder.path, modname)
         yield subpackage_path
+
+
+def format_api_object(obj):
+    if obj.get('created'):
+        obj['created'] = int(obj['created'].timestamp())
+    if obj.get('updated'):
+        obj['updated'] = int(obj['updated'].timestamp())
+    return obj
