@@ -7,6 +7,7 @@ def get_logger():
 
 
 def log_event(level, start, end, status, process_type, payload, attributes=None, failure_classification=None):
+    import json
     assert isinstance(payload, dict)
     assert isinstance(attributes, dict) or attributes is None
     assert status in {'success', 'anomalous', 'failure', 're-queued'}
@@ -26,5 +27,5 @@ def log_event(level, start, end, status, process_type, payload, attributes=None,
         "attributes": attributes if attributes is not None else {},
         "payload": payload
     }
-    get_logger().log(level=level_mapping[level.lower()], msg=log_message)
-    return log_message
\ No newline at end of file
+    get_logger().log(level=level_mapping[level.lower()], msg=json.dumps(log_message))
+    return log_message
